#
# spec file for package vale
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vale
Version:        2.28.3
Release:        bp156.1.6
Summary:        CLI tool to lint prose text with syntax awareneness and extensible markup format support
License:        MIT
Group:          Productivity/Text/Utilities
URL:            https://github.com/errata-ai/vale
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.20

%description
Vale is a command-line tool that brings code-like linting to prose. It's fast,
cross-platform (Windows, macOS, and Linux), and highly customizable.

Vale has support for markup: Vale has a rich understanding of many markup
formats, allowing it to avoid syntax-related false positives and intelligently
exclude code snippets from prose-related rules.

Vale includes a highly customizable extension system capable of enforcing your
style-be it a standard editorial style guide or a custom in-house set of rules
(such as those created by GitLab, Homebrew, Linode, CockroachDB, and Spotify).

https://vale.sh/

%prep
%autosetup -a 1

%build
# Build the binary.
go build \
   -mod=vendor \
   -tags extended \
   -buildmode=pie \
   ./cmd/vale

%check
# execute the binary as a basic check
./%{name} --help

%install
# Install the binary.
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"
# Install empty styles directory for use by other packages
install --directory %{buildroot}%{_datarootdir}/%{name}/styles

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
# Package empty styles directory for use by other packages
%dir %{_datarootdir}/%{name}
%dir %{_datarootdir}/%{name}/styles

%changelog
* Thu Sep  7 2023 jkowalczyk@suse.com
- Update to version 2.28.3:
  * fix: workaround `blk.Line` inconsistency
  * fix: take the best match, when available
  * fix: don't concatenate an empty regex
  * fix: `metric` shouldn't error on empty files
  * fix: ignore statichcheck for seqence history
  * chore: fix workflow branch for golangci
  * test: update expected error message
  * chore: add workflow for golangci
  * chore: get `cmd` passing new CI config
  * chore: get `check` passing new CI config
  * chore: get `core` passing new ci config
  * chore: get `spell` passing new ci config
  * chore: get `nlp` passing new ci config
  * chore: get `lint` passing new golangci config
  * chore: update `goldmark` and `net`
* Thu Aug 17 2023 jkowalczyk@suse.com
- Update to version 2.28.2:
  * test: add case for pkg 404
  * fix: improve error message for non-existant pkgs
  * docs: add 'Appwrite' to vocab
  * docs: add Appwrite
* Tue Jul 25 2023 jkowalczyk@suse.com
- Update to version 2.28.1:
  * fix: ensure hypenated exceptions are respected
  * fix: allow hypenated words in `Vale.Terms`
  * test: fix inline scope cases
  * refactor: validate `scope`
* Tue Jul  4 2023 jkowalczyk@suse.com
- Update to version 2.28.0:
  * fix: set base path for `VALE_CONFIG_PATH`
  * feat: support `VALE_CONFIG_PATH`
  * fix: normalizePath tilde expansion on Windows (#656)
  * fix: update GitLab CI
  * feat: add clojure support (#649)
  * refactor: make capitalization threshold `>=`
  * docs: typo
  * fix: broken README.md link
  * Update README.md (#638)
* Tue May 23 2023 jkowalczyk@suse.com
- Update to version 2.27.0:
  * test: add more Package cases
  * feat: support ignoring `comment` scopes
  * fix: ensure `raw`-scoped rules are run on code
* Thu May 11 2023 jkowalczyk@suse.com
- Update to version 2.26.0:
  * test: add case for dics in `StylesPath`
  * refactor: support templates in `StylesPath`
  * fix: allow `-` in `code::` blocks
  * chore: fix `make compare`
  * chore: clean up Makefile
  * refactor: deprecate dedicated inline scopes
  * refactor: deprecate dedicated inline scopes
  * refactor: fallback to CLI if local server fails
  * docs: Add DigitalOcean
* Thu Apr 27 2023 jkowalczyk@suse.com
- Update to version 2.25.2:
  * fix: rollback file view changes for now
* Thu Apr 27 2023 jkowalczyk@suse.com
- Update to version 2.25.1:
  * fix: revert godirwalk upgrade
  * chore: fix AppVeyor
  * chore: bump Go in Docker
* Thu Apr 27 2023 jkowalczyk@suse.com
- Update to version 2.25.0:
  * chore: fix version
  * chore: bump checkout
  * chore: upgrade GoReleaser [ci skip]
  * chore: bump Go
  * test: fix templates
  * chore: update `godirwalk`
  * refactor: add NOTE about `os`
  * test: add another template case
  * chore: update Go to 1.20
  * refactor: use `unsafe.StringData` to keep multiple file views
  * feat: support comment-based config on Org Mode
  * docs: add NOTE about `Substitute`
  * refactor: use `Strings.Replace` in `Substitute`
  * chore: add `make profile`
  * chore: update `go-org`
  * chore: update sprig
  * chore: fix `make bench`
  * chore: update `archiver`
  * chore: bump Go version
  * test: add fuzzing to `existence`
  * chore: remove redundant section from feat template
  * chore: remove word-wrapping
  * chore: fix bug report wording
- Packaging: BuildRequires: golang(API) >= 1.20
* Thu Apr 27 2023 jkowalczyk@suse.com
- Update to version 2.24.4:
  * fix: don't call `re2loc` in `script`-based rules
  * fix: support symlinks in `dicpath`
  * docs: Add Studio to README
  * New ISSUE_TEMPLATE
  * chore: move `CODE_OF_CONDUCT`
  * Create CODE_OF_CONDUCT.md
  * fix: check bounds on tags
  * test: add case for custom threshold
  * test: add Packages tests
  * fix: check bounds for `scope: raw`
* Tue Apr 18 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Remove NO_BRP_STRIP_DEBUG=true experimentally to test which if
  any platforms in OBS currently produce invalid Go binaries when
  calling brp-15-strip-debug from brp-check-suse.
  Refs boo#1210938
  * Go packages %%define __arch_install_post export NO_BRP_STRIP_DEBUG=true
  * Available in golang-packaging as macro go_nostrip
  * go_nostrip is one of the only golang-packaging macros still
    useful after Go modules without a full rewrite or replacement
  * Also remove spec comment "# nodebug"
  * GNU strip circa 2016 would incorrectly strip Go intermediate
    step .a archives and write out an invalid binary instead of
    erroring.
  * Error manifested as fmt.a: go archive is missing __.PKGDEF
    on OBS built Go binaries which had passed their build step
  * Upstream issue reported in 2016 as
    https://github.com/golang/go/issues/17890
  * brp-check-suse PR https://github.com/openSUSE/brp-check-suse/pull/7
    closed in 2019 due to age, needs follow-up on current versions
* Tue Apr 18 2023 jkowalczyk@suse.com
- Update to version 2.24.3:
  * test: add `occurrence` case
  * fix: don't crash on no `extends`
* Sun Apr 16 2023 jkowalczyk@suse.com
- Update to version 2.24.2:
  * fix: ensure `negate` is always checked for tags
  * fix: don't make tmpdir for local pkg
  * fix: set config defaults
  * refactor: don't require config for metrics
  * refactor: don't require config in `run`
  * feat: better error for unknown keys
  * refactor: don't require `.vale.ini` for `compile`
  * refactor: match case in returned suggestions
  * chore: update choco
* Sun Apr  9 2023 jkowalczyk@suse.com
- Update to version 2.24.1:
  * refactor: unknown keys are now an error
  * (GH-597) Find config in home folder as last resort (#598)
  * feat: support multi-part selectors
  * (MAINT) Add tests for PowerShell code linting (#586)
- Use _service mode manual as better alias name than disabled
* Mon Mar  6 2023 jkowalczyk@suse.com
- Update to version 2.24.0:
  * fix: string -> interface
  * refactor: drop `bindata` dep
  * feat: support negated scopes
  * fix: use a temp dir in `loadLocalPkg`
  * feat: improve handling for misplaced keys
  * chore: fix `.ArtifactName`
* Tue Feb 28 2023 jkowalczyk@suse.com
- Update to version 2.23.3:
  * chore: fix naming again
* Tue Feb 28 2023 jkowalczyk@suse.com
- Update to version 2.23.2:
  * fix: asset naming scheme
* Tue Feb 28 2023 jkowalczyk@suse.com
- Update to version 2.23.1:
  * chore: remove `id`
  * chore: remove `--clean`
  * chore: fix `name_template`
  * chore: remove `archives.replacements`
  * chore: fix GoReleaser
  * chore: clean up workflows
  * fix: CLI test isn't deterministic
  * fix: include `.vale.ini` in action tests
  * chore: bring back `chocolateys`
  * test: start action cases
  * refactor: remove old TODO
  * refactor: remove `pkg`
  * fix: handle trailing commas in listing block
  * Add PowerShell as a supported code language (#579)
  * feat: support Typescript, TSX and JSX files (#564)
  * fix: use `determinePath` in `Transform`
  * fix: ignore empty tokens
  * fix: trim leading newlines from sentences
* Sat Feb 11 2023 jkowalczyk@suse.com
- Update to version 2.23.0:
  * fix: create `lintTxt`
  * chore: update go.mod
  * feat: add `--filter`
  * feat: Add pre-commit support (#558)
  * chore: update runner name
  * Add `perf` workflow
  * docs: fix typos (#553)
  * chore: set version for Docker
* Wed Jan 18 2023 jkowalczyk@suse.com
- Update to version 2.22.0:
  * chore: disable choco step for now
  * chore: add `ldflags`
  * chore: add `goos` section
  * chore: specify `choco` version
  * chore: install `choco`
  * chore: fix docker version
  * Add choco section to GoReleaser
  * Remove `atom` files
  * refactor: remove outdated `HasUpdate` check
  * Allow for more generic errors in loadPkg (#543)
  * Fix dic count
  * fix: add `SM` to metric
  * docs: update year
  * chore: fix excutable name
  * feat: install package from local directory (#534)
  * chore: use `docker buildx`
* Wed Dec 14 2022 jkowalczyk@suse.com
- Update to version 2.21.3:
  * refactor: remove debug message
  * fix: always use last `StylesPath` loaded
  * feat(config): expand ~ to home directory (#530)
  * refactor: remove `ioutil`
  * fix: don't treat `span` as a block
* Thu Nov 24 2022 jkowalczyk@suse.com
- Update to version 2.21.2:
  * fix: allow `.vale` in `StylesPath`
  * fix: allow `.vale` in `StylesPath`
  * refactor: add note about `os` module
  * feat: enable access to `os` module in `script`
* Thu Nov 24 2022 jkowalczyk@suse.com
- Update to version 2.21.1:
  * test: re-enable Non-Existent case
  * refactor: remove `StylesPath` from example config
  * fix: remove override logic from `loadConfig`
  * feat: support using local and system dics
  * docs: comment typo
  * fix: correctly resolve `dicpath`
  * Add CodeQL workflow
  * feat: enable Goldmark's footnote extension
  * chore: ignore `.fleet`
  * refactor: align structs
  * fix: report exact Asciidoctor error
* Fri Oct 28 2022 jkowalczyk@suse.com
- Update to version 2.21.0:
  * test: add another case for `IgnoredClasses`
  * refactor: report actual XML error message
  * test: add table test case for `IgnoredClasses`
  * docs: update `.vale.ini` config
  * docs: update `.vale.ini` config
  * docs: update `.vale.ini` config
  * feat: support comments in ignore files
  * feat: ignore blocks by class
  * fix: handle `0` suffix
  * fix: `skip` should be an upper bound
  * fix: `skip` should be an upper bound
  * fix: ensure sequence length is non-zero
  * feat: load local packages
  * chore: restore Dockerfile
  * chore: restore Dockerfile
* Wed Oct 12 2022 Jeff Kowalczyk <jkowalczyk@suse.com>
- Add empty directory /usr/share/vale/styles for use by other
  packages to install vale styles. Use a shortname directory per
  style package, e.g. /usr/share/vale/styles/suse
* Wed Sep 14 2022 jkowalczyk@suse.com
- Update to version 2.20.2:
  * chore: fix main package
  * chore: fix Go version for GoReleaser
  * refactor: remove old doc.go
  * refactor: remove old doc.go
  * Consistent color reporting
  * refactor: remove unused error
  * refactor: remove `internal/cli`
  * refactor: remove `internal/cli`
  * fix: support numbers in Vocab entries
* Sun Jul 24 2022 jkowalczyk@suse.com
- Update to version 2.20.1:
  * refactor: fix `IsPhrase` tests
  * test: add tests for `IsPhrase`
  * refactor: add missing `doc.go`
  * fix: set action params
  * fix: improve error message
  * fix: check all error conditions
  * Fix: Enable PIE mode
  * Fix: Remove exec bit from docs
  * docs: add Org support
* Tue Jul  5 2022 jkowalczyk@suse.com
- Update to version 2.20.0:
  * chore: add workflow to bump pkgs
  * fix: check `head` indexes before removing
  * feat: support ignore patterns in Org
  * chore: bump Go version
  * test: add another Org case
  * feat: add support for Org files
* Fri Jul  1 2022 jkowalczyk@suse.com
- Initial package version 2.19.0:
  * chore: add dispatch step
  * refactor: remove unused param
  * feat: support tag matching for sequence anchor
  * chore: build linux_arm64
  * chore: move fixtures to testdata
  * chore: move pkg managers to their own repo
  * chore: add chocolatey files
  * feat: more patterns
  * refactor: remove manual offset
  * fix: use line index as comment offset
  * chore: mark fixtures as vendored
  * chore: remove lgtm.yml
  * chore: mark `testdata` as vendored
  * feat: support embedded markup
  * docs: update link
